diff Core/OrthancException.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents 6da7fc87efaa
children fe180eae201d
line wrap: on
line diff
--- a/Core/OrthancException.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/OrthancException.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -18,11 +18,11 @@
  **/
 
 
-#include "PalanthirException.h"
+#include "OrthancException.h"
 
-namespace Palanthir
+namespace Orthanc
 {
-  const char* PalanthirException::What() const
+  const char* OrthancException::What() const
   {
     if (error_ == ErrorCode_Custom)
     {
@@ -35,7 +35,7 @@
   }
 
 
-  const char* PalanthirException::GetDescription(ErrorCode error)
+  const char* OrthancException::GetDescription(ErrorCode error)
   {
     switch (error)
     {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium